Installing and using SageTeX
============================

SageTeX is a system for embedding computations and plots from Sage into
LaTeX documents. It is included by default with Sage, so if you have
installed Sage, you already have SageTeX. However, to get it to work,
you need to make TeX aware of SageTeX. Instructions for that are in the
`Make SageTeX known to TeX
<http://doc.sagemath.org/html/en/tutorial/sagetex.html#make-sagetex-known-to-tex>`_
section of the `Sage tutorial
<http://doc.sagemath.org/html/en/tutorial/index.html>`_ (`this link
<../../tutorial/index.html>`_ should take you to a local copy of the
tutorial).
